qemu-devel
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

[Qemu-devel] [PATCH] isapc: Shadow ISA BIOS by default


From: Jan Kiszka
Subject: [Qemu-devel] [PATCH] isapc: Shadow ISA BIOS by default
Date: Tue, 11 Sep 2012 17:53:56 +0200
User-agent: Mozilla/5.0 (X11; U; Linux i686 (x86_64); de; rv:1.8.1.12) Gecko/20080226 SUSE/2.0.0.12-1.1 Thunderbird/2.0.0.12 Mnenhy/0.7.5.666

Our one and only BIOS depends on a writable shadowed BIOS in the ISA
range. As we have no interface to control the write property, make that
region writable by default.

Signed-off-by: Jan Kiszka <address@hidden>
---

This unbreaks isapc for TCG, and keep it working for KVM once it starts
supporting read-only memslots.

 hw/pc_sysfw.c |   13 +++++++++----
 1 files changed, 9 insertions(+), 4 deletions(-)

diff --git a/hw/pc_sysfw.c b/hw/pc_sysfw.c
index b45f0ac..027d98a 100644
--- a/hw/pc_sysfw.c
+++ b/hw/pc_sysfw.c
@@ -136,6 +136,7 @@ static void old_pc_system_rom_init(MemoryRegion *rom_memory)
 {
     char *filename;
     MemoryRegion *bios, *isa_bios;
+    void *isa_bios_ptr;
     int bios_size, isa_bios_size;
     int ret;
 
@@ -167,19 +168,23 @@ static void old_pc_system_rom_init(MemoryRegion 
*rom_memory)
         g_free(filename);
     }
 
     /* map the last 128KB of the BIOS in ISA space */
     isa_bios_size = bios_size;
     if (isa_bios_size > (128 * 1024)) {
         isa_bios_size = 128 * 1024;
     }
     isa_bios = g_malloc(sizeof(*isa_bios));
-    memory_region_init_alias(isa_bios, "isa-bios", bios,
-                             bios_size - isa_bios_size, isa_bios_size);
+    memory_region_init_ram(isa_bios, "isa-bios", isa_bios_size);
+    vmstate_register_ram_global(isa_bios);
     memory_region_add_subregion_overlap(rom_memory,
                                         0x100000 - isa_bios_size,
                                         isa_bios,
                                         1);
-    memory_region_set_readonly(isa_bios, true);
+
+    /* copy ISA rom image from top of the ROM */
+    isa_bios_ptr = memory_region_get_ram_ptr(isa_bios);
+    rom_copy(isa_bios_ptr, (uint32_t)(-isa_bios_size), isa_bios_size);
 
     /* map all the bios at the top of memory */
     memory_region_add_subregion(rom_memory,
@@ -167,19 +168,23 @@ static void old_pc_system_rom_init(MemoryRegion 
     }
 
-    /* map the last 128KB of the BIOS in ISA space */
+    /* Shadow the last 128KB of the BIOS in ISA space as RAM -
+     * Seabios depends on this */
     isa_bios_size = bios_size;
     if (isa_bios_size > (128 * 1024)) {
-- 
1.7.3.4



reply via email to

[Prev in Thread] Current Thread [Next in Thread]